@@ -21,9 +21,10 @@ import {
   IntervalVariable,
   QueryVariable,
   SceneVariableSet,
+  SwitchVariable,
   TextBoxVariable,
 } from '@grafana/scenes';
-import { DataSourceRef, VariableRefresh } from '@grafana/schema';
+import { DataSourceRef, VariableHide, VariableRefresh } from '@grafana/schema';
 
 import { sceneVariablesSetToSchemaV2Variables, sceneVariablesSetToVariables } from './sceneVariablesSetToVariables';
 
@@ -93,7 +94,7 @@ describe('sceneVariablesSetToVariables', () => {
       name: 'test',
       label: 'test-label',
       description: 'test-desc',
-      showInControlsMenu: true,
+      hide: VariableHide.inControlsMenu,
       value: ['selected-value'],
       text: ['selected-value-text'],
       datasource: { uid: 'fake-uid', type: 'fake-type' },
@@ -131,6 +132,7 @@ describe('sceneVariablesSetToVariables', () => {
       },
       "definition": undefined,
       "description": "test-desc",
+      "hide": 3,
       "includeAll": true,
       "label": "test-label",
       "multi": true,
@@ -139,7 +141,7 @@ describe('sceneVariablesSetToVariables', () => {
       "query": "query",
       "refresh": 1,
       "regex": "",
-      "showInControlsMenu": true,
+      "regexApplyTo": "value",
       "staticOptions": [
         {
           "text": "test",
@@ -157,7 +159,7 @@ describe('sceneVariablesSetToVariables', () => {
       name: 'test',
       label: 'test-label',
       description: 'test-desc',
-      showInControlsMenu: true,
+      hide: VariableHide.inControlsMenu,
       value: ['selected-value'],
       text: ['selected-value-text'],
       datasource: { uid: 'fake-uid', type: 'fake-type' },
@@ -195,6 +197,7 @@ describe('sceneVariablesSetToVariables', () => {
       },
       "definition": "query",
       "description": "test-desc",
+      "hide": 3,
       "includeAll": true,
       "label": "test-label",
       "multi": true,
@@ -203,7 +206,7 @@ describe('sceneVariablesSetToVariables', () => {
       "query": "query",
       "refresh": 1,
       "regex": "",
-      "showInControlsMenu": true,
+      "regexApplyTo": "value",
       "staticOptions": [
         {
           "text": "test",
@@ -221,7 +224,7 @@ describe('sceneVariablesSetToVariables', () => {
       name: 'test',
       label: 'test-label',
       description: 'test-desc',
-      showInControlsMenu: true,
+      hide: VariableHide.inControlsMenu,
       value: ['selected-value'],
       text: ['selected-value-text'],
       datasource: { uid: 'fake-uid', type: 'fake-type' },
@@ -249,7 +252,7 @@ describe('sceneVariablesSetToVariables', () => {
       name: 'test',
       label: 'test-label',
       description: 'test-desc',
-      showInControlsMenu: true,
+      hide: VariableHide.inControlsMenu,
       value: ['test'],
       text: ['test'],
       datasource: { uid: 'fake-uid', type: 'fake-type' },
@@ -279,7 +282,7 @@ describe('sceneVariablesSetToVariables', () => {
       name: 'test',
       label: 'test-label',
       description: 'test-desc',
-      showInControlsMenu: true,
+      hide: VariableHide.inControlsMenu,
       value: ['selected-ds-1', 'selected-ds-2'],
       text: ['selected-ds-1-text', 'selected-ds-2-text'],
       pluginId: 'fake-std',
@@ -310,6 +313,7 @@ describe('sceneVariablesSetToVariables', () => {
         ],
       },
       "description": "test-desc",
+      "hide": 3,
       "includeAll": true,
       "label": "test-label",
       "multi": true,
@@ -318,7 +322,6 @@ describe('sceneVariablesSetToVariables', () => {
       "query": "fake-std",
       "refresh": 1,
       "regex": "",
-      "showInControlsMenu": true,
       "type": "datasource",
     }
     `);
@@ -329,7 +332,7 @@ describe('sceneVariablesSetToVariables', () => {
       name: 'test',
       label: 'test-label',
       description: 'test-desc',
-      showInControlsMenu: true,
+      hide: VariableHide.inControlsMenu,
       value: ['test', 'test2'],
       text: ['test', 'test2'],
       query: 'test,test1,test2',
@@ -365,40 +368,54 @@ describe('sceneVariablesSetToVariables', () => {
         ],
       },
       "description": "test-desc",
+      "hide": 3,
       "includeAll": true,
       "label": "test-label",
       "multi": true,
       "name": "test",
-      "options": [
-        {
-          "selected": true,
-          "text": "test",
-          "value": "test",
-        },
-        {
-          "selected": false,
-          "text": "test1",
-          "value": "test1",
-        },
-        {
-          "selected": true,
-          "text": "test2",
-          "value": "test2",
-        },
-      ],
+      "options": [],
       "query": "test,test1,test2",
-      "showInControlsMenu": true,
       "type": "custom",
+      "valuesFormat": "csv",
     }
     `);
   });
 
+  it('should handle Custom variable when sceneVariablesSetToVariables should keep options', () => {
+    const variable = new CustomVariable({
+      name: 'test',
+      label: 'test-label',
+      description: 'test-desc',
+      hide: VariableHide.inControlsMenu,
+      value: ['test'],
+      text: ['test'],
+      query: 'test,test1,test2',
+      options: [
+        { label: 'test', value: 'test' },
+        { label: 'test1', value: 'test1' },
+        { label: 'test2', value: 'test2' },
+      ],
+      includeAll: true,
+      allValue: 'test-all',
+      isMulti: true,
+    });
+
+    const set = new SceneVariableSet({
+      variables: [variable],
+    });
+    const keepQueryOptions = true;
+    const result = sceneVariablesSetToVariables(set, keepQueryOptions);
+    expect(result).toHaveLength(1);
+    expect(result[0].options).not.toEqual([]);
+    expect(result[0].options?.length).toEqual(3);
+  });
+
   it('should handle ConstantVariable', () => {
     const variable = new ConstantVariable({
       name: 'test',
       label: 'test-label',
       description: 'test-desc',
-      showInControlsMenu: true,
+      hide: VariableHide.inControlsMenu,
       value: 'constant value',
       skipUrlSync: true,
     });
@@ -420,7 +437,6 @@ describe('sceneVariablesSetToVariables', () => {
       "label": "test-label",
       "name": "test",
       "query": "constant value",
-      "showInControlsMenu": true,
       "skipUrlSync": true,
       "type": "constant",
     }
@@ -432,7 +448,7 @@ describe('sceneVariablesSetToVariables', () => {
       name: 'test',
       label: 'test-label',
       description: 'test-desc',
-      showInControlsMenu: true,
+      hide: VariableHide.inControlsMenu,
       value: 'text value',
       skipUrlSync: true,
     });
@@ -450,6 +466,7 @@ describe('sceneVariablesSetToVariables', () => {
         "value": "text value",
       },
       "description": "test-desc",
+      "hide": 3,
       "label": "test-label",
       "name": "test",
       "options": [
@@ -460,7 +477,6 @@ describe('sceneVariablesSetToVariables', () => {
         },
       ],
       "query": "text value",
-      "showInControlsMenu": true,
       "skipUrlSync": true,
       "type": "textbox",
     }
@@ -472,7 +488,7 @@ describe('sceneVariablesSetToVariables', () => {
       intervals: ['1m', '2m', '3m', '1h', '1d'],
       value: '1m',
       refresh: VariableRefresh.onDashboardLoad,
-      showInControlsMenu: true,
+      hide: VariableHide.inControlsMenu,
     });
     const set = new SceneVariableSet({
       variables: [variable],
@@ -490,6 +506,7 @@ describe('sceneVariablesSetToVariables', () => {
         "value": "1m",
       },
       "description": undefined,
+      "hide": 3,
       "label": undefined,
       "name": "",
       "options": [
@@ -521,7 +538,6 @@ describe('sceneVariablesSetToVariables', () => {
       ],
       "query": "1m,2m,3m,1h,1d",
       "refresh": 1,
-      "showInControlsMenu": true,
       "type": "interval",
     }
     `);
@@ -533,7 +549,7 @@ describe('sceneVariablesSetToVariables', () => {
       allowCustomValue: true,
       label: 'test-label',
       description: 'test-desc',
-      showInControlsMenu: true,
+      hide: VariableHide.inControlsMenu,
       datasource: { uid: 'fake-uid', type: 'fake-type' },
       filters: [
         {
@@ -580,9 +596,9 @@ describe('sceneVariablesSetToVariables', () => {
           "value": "test",
         },
       ],
+      "hide": 3,
       "label": "test-label",
       "name": "test",
-      "showInControlsMenu": true,
       "type": "adhoc",
     }
     `);
@@ -595,7 +611,7 @@ describe('sceneVariablesSetToVariables', () => {
         allowCustomValue: true,
         label: 'test-label',
         description: 'test-desc',
-        showInControlsMenu: true,
+        hide: VariableHide.inControlsMenu,
         datasource: { uid: 'fake-std', type: 'fake-std' },
         originFilters: [
           {
@@ -625,9 +641,9 @@ describe('sceneVariablesSetToVariables', () => {
         "defaultKeys": undefined,
         "description": "test-desc",
         "filters": [],
+        "hide": 3,
         "label": "test-label",
         "name": "test",
-        "showInControlsMenu": true,
         "type": "adhoc",
       }
       `);
@@ -639,7 +655,7 @@ describe('sceneVariablesSetToVariables', () => {
         allowCustomValue: true,
         label: 'test-label',
         description: 'test-desc',
-        showInControlsMenu: true,
+        hide: VariableHide.inControlsMenu,
         datasource: { uid: 'fake-std', type: 'fake-std' },
         originFilters: [
           {
@@ -687,9 +703,9 @@ describe('sceneVariablesSetToVariables', () => {
             "value": "test2",
           },
         ],
+        "hide": 3,
         "label": "test-label",
         "name": "test",
-        "showInControlsMenu": true,
         "type": "adhoc",
       }
       `);
@@ -702,7 +718,7 @@ describe('sceneVariablesSetToVariables', () => {
       allowCustomValue: true,
       label: 'test-label',
       description: 'test-desc',
-      showInControlsMenu: true,
+      hide: VariableHide.inControlsMenu,
       datasource: { uid: 'fake-uid', type: 'fake-type' },
       defaultKeys: [
         {
@@ -776,9 +792,9 @@ describe('sceneVariablesSetToVariables', () => {
           "value": "test",
         },
       ],
+      "hide": 3,
       "label": "test-label",
       "name": "test",
-      "showInControlsMenu": true,
       "type": "adhoc",
     }
     `);
@@ -799,7 +815,7 @@ describe('sceneVariablesSetToVariables', () => {
         label: 'test-label',
         description: 'test-desc',
         allowCustomValue: true,
-        showInControlsMenu: true,
+        hide: VariableHide.inControlsMenu,
         datasource: { uid: 'fake-uid', type: 'fake-type' },
         defaultOptions: [
           {
@@ -832,6 +848,7 @@ describe('sceneVariablesSetToVariables', () => {
         },
         "defaultValue": undefined,
         "description": "test-desc",
+        "hide": 3,
         "label": "test-label",
         "name": "test",
         "options": [
@@ -844,7 +861,6 @@ describe('sceneVariablesSetToVariables', () => {
             "value": "bar",
           },
         ],
-        "showInControlsMenu": true,
         "type": "groupby",
       }
       `);
@@ -857,7 +873,7 @@ describe('sceneVariablesSetToVariables', () => {
         name: 'test',
         label: 'test-label',
         description: 'test-desc',
-        showInControlsMenu: true,
+        hide: VariableHide.inControlsMenu,
         datasource: { uid: 'fake-uid', type: 'fake-type' },
         defaultOptions: [
           {
@@ -878,6 +894,168 @@ describe('sceneVariablesSetToVariables', () => {
     });
   });
 
+  it('should handle SwitchVariable with "true" value', () => {
+    const variable = new SwitchVariable({
+      name: 'test',
+      label: 'test-label',
+      description: 'test-desc',
+      hide: VariableHide.inControlsMenu,
+      value: 'true',
+      skipUrlSync: true,
+    });
+    const set = new SceneVariableSet({
+      variables: [variable],
+    });
+
+    const result = sceneVariablesSetToVariables(set);
+
+    expect(result).toHaveLength(1);
+    expect(result[0]).toMatchInlineSnapshot(`
+{
+  "current": {
+    "text": "true",
+    "value": "true",
+  },
+  "description": "test-desc",
+  "hide": 3,
+  "label": "test-label",
+  "name": "test",
+  "options": [
+    {
+      "text": "true",
+      "value": "true",
+    },
+    {
+      "text": "false",
+      "value": "false",
+    },
+  ],
+  "skipUrlSync": true,
+  "type": "switch",
+}
+`);
+  });
+
+  it('should handle SwitchVariable with "false" value', () => {
+    const variable = new SwitchVariable({
+      name: 'test',
+      label: 'test-label',
+      description: 'test-desc',
+      hide: VariableHide.inControlsMenu,
+      value: 'false',
+      skipUrlSync: false,
+    });
+    const set = new SceneVariableSet({
+      variables: [variable],
+    });
+
+    const result = sceneVariablesSetToVariables(set);
+
+    expect(result).toHaveLength(1);
+    expect(result[0]).toMatchInlineSnapshot(`
+{
+  "current": {
+    "text": "false",
+    "value": "false",
+  },
+  "description": "test-desc",
+  "hide": 3,
+  "label": "test-label",
+  "name": "test",
+  "options": [
+    {
+      "text": "true",
+      "value": "true",
+    },
+    {
+      "text": "false",
+      "value": "false",
+    },
+  ],
+  "type": "switch",
+}
+`);
+  });
+
+  it('should handle SwitchVariable with custom values', () => {
+    const variable = new SwitchVariable({
+      name: 'test',
+      label: 'test-label',
+      description: 'test-desc',
+      hide: VariableHide.inControlsMenu,
+      value: 'on',
+      enabledValue: 'on',
+      disabledValue: 'off',
+      skipUrlSync: false,
+    });
+    const set = new SceneVariableSet({
+      variables: [variable],
+    });
+
+    const result = sceneVariablesSetToVariables(set);
+
+    expect(result).toHaveLength(1);
+    expect(result[0]).toMatchInlineSnapshot(`
+{
+  "current": {
+    "text": "on",
+    "value": "on",
+  },
+  "description": "test-desc",
+  "hide": 3,
+  "label": "test-label",
+  "name": "test",
+  "options": [
+    {
+      "text": "on",
+      "value": "on",
+    },
+    {
+      "text": "off",
+      "value": "off",
+    },
+  ],
+  "type": "switch",
+}
+`);
+  });
+
+  it('should handle SwitchVariable with minimal configuration', () => {
+    const variable = new SwitchVariable({
+      name: 'minimal',
+      value: 'true',
+    });
+    const set = new SceneVariableSet({
+      variables: [variable],
+    });
+
+    const result = sceneVariablesSetToVariables(set);
+
+    expect(result).toHaveLength(1);
+    expect(result[0]).toMatchInlineSnapshot(`
+{
+  "current": {
+    "text": "true",
+    "value": "true",
+  },
+  "description": undefined,
+  "label": undefined,
+  "name": "minimal",
+  "options": [
+    {
+      "text": "true",
+      "value": "true",
+    },
+    {
+      "text": "false",
+      "value": "false",
+    },
+  ],
+  "type": "switch",
+}
+`);
+  });
+
   describe('sceneVariablesSetToSchemaV2Variables', () => {
     it('should handle QueryVariable', () => {
       const variable = new QueryVariable({
@@ -893,7 +1071,7 @@ describe('sceneVariablesSetToVariables', () => {
         isMulti: true,
         staticOptions: [{ label: 'test', value: 'test' }],
         staticOptionsOrder: 'after',
-        showInControlsMenu: true,
+        hide: VariableHide.inControlsMenu,
       });
 
       const set = new SceneVariableSet({
@@ -919,7 +1097,7 @@ describe('sceneVariablesSetToVariables', () => {
             },
             "definition": undefined,
             "description": "test-desc",
-            "hide": "dontHide",
+            "hide": "inControlsMenu",
             "includeAll": true,
             "label": "test-label",
             "multi": true,
@@ -938,7 +1116,7 @@ describe('sceneVariablesSetToVariables', () => {
             },
             "refresh": "onDashboardLoad",
             "regex": "",
-            "showInControlsMenu": true,
+            "regexApplyTo": "value",
             "skipUrlSync": false,
             "sort": "disabled",
             "staticOptions": [
@@ -961,7 +1139,7 @@ describe('sceneVariablesSetToVariables', () => {
         value: ['test', 'test2'],
         text: ['test', 'test2'],
         query: 'test,test1,test2',
-        showInControlsMenu: true,
+        hide: VariableHide.inControlsMenu,
         options: [
           { label: 'test', value: 'test' },
           { label: 'test1', value: 'test1' },
@@ -995,31 +1173,15 @@ describe('sceneVariablesSetToVariables', () => {
           ],
         },
         "description": "test-desc",
-        "hide": "dontHide",
+        "hide": "inControlsMenu",
         "includeAll": true,
         "label": "test-label",
         "multi": true,
         "name": "test",
-        "options": [
-          {
-            "selected": true,
-            "text": "test",
-            "value": "test",
-          },
-          {
-            "selected": false,
-            "text": "test1",
-            "value": "test1",
-          },
-          {
-            "selected": true,
-            "text": "test2",
-            "value": "test2",
-          },
-        ],
+        "options": [],
         "query": "test,test1,test2",
-        "showInControlsMenu": true,
         "skipUrlSync": false,
+        "valuesFormat": "csv",
       },
     }
     `);
@@ -1036,7 +1198,7 @@ describe('sceneVariablesSetToVariables', () => {
         includeAll: true,
         allValue: 'test-all',
         isMulti: true,
-        showInControlsMenu: true,
+        hide: VariableHide.inControlsMenu,
       });
       const set = new SceneVariableSet({
         variables: [variable],
@@ -1062,7 +1224,7 @@ describe('sceneVariablesSetToVariables', () => {
           ],
         },
         "description": "test-desc",
-        "hide": "dontHide",
+        "hide": "inControlsMenu",
         "includeAll": true,
         "label": "test-label",
         "multi": true,
@@ -1071,7 +1233,6 @@ describe('sceneVariablesSetToVariables', () => {
         "pluginId": "fake-std",
         "refresh": "onDashboardLoad",
         "regex": "",
-        "showInControlsMenu": true,
         "skipUrlSync": false,
       },
     }
@@ -1084,7 +1245,7 @@ describe('sceneVariablesSetToVariables', () => {
         label: 'test-label',
         description: 'test-desc',
         value: 'constant value',
-        showInControlsMenu: true,
+        hide: VariableHide.inControlsMenu,
         skipUrlSync: true,
       });
       const set = new SceneVariableSet({
@@ -1103,11 +1264,10 @@ describe('sceneVariablesSetToVariables', () => {
           "value": "constant value",
         },
         "description": "test-desc",
-        "hide": "dontHide",
+        "hide": "inControlsMenu",
         "label": "test-label",
         "name": "test",
         "query": "constant value",
-        "showInControlsMenu": true,
         "skipUrlSync": true,
       },
     }
@@ -1120,7 +1280,7 @@ describe('sceneVariablesSetToVariables', () => {
         label: 'test-label',
         description: 'test-desc',
         value: 'text value',
-        showInControlsMenu: true,
+        hide: VariableHide.inControlsMenu,
         skipUrlSync: true,
       });
       const set = new SceneVariableSet({
@@ -1139,11 +1299,10 @@ describe('sceneVariablesSetToVariables', () => {
           "value": "text value",
         },
         "description": "test-desc",
-        "hide": "dontHide",
+        "hide": "inControlsMenu",
         "label": "test-label",
         "name": "test",
         "query": "text value",
-        "showInControlsMenu": true,
         "skipUrlSync": true,
       },
     }
@@ -1154,7 +1313,7 @@ describe('sceneVariablesSetToVariables', () => {
       const variable = new IntervalVariable({
         intervals: ['1m', '2m', '3m', '1h', '1d'],
         value: '1m',
-        showInControlsMenu: true,
+        hide: VariableHide.inControlsMenu,
         refresh: VariableRefresh.onDashboardLoad,
       });
       const set = new SceneVariableSet({
@@ -1175,7 +1334,7 @@ describe('sceneVariablesSetToVariables', () => {
           "value": "1m",
         },
         "description": undefined,
-        "hide": "dontHide",
+        "hide": "inControlsMenu",
         "label": undefined,
         "name": "",
         "options": [
@@ -1207,7 +1366,6 @@ describe('sceneVariablesSetToVariables', () => {
         ],
         "query": "1m,2m,3m,1h,1d",
         "refresh": "onTimeRangeChanged",
-        "showInControlsMenu": true,
         "skipUrlSync": false,
       },
     }
@@ -1219,7 +1377,7 @@ describe('sceneVariablesSetToVariables', () => {
         name: 'test',
         label: 'test-label',
         description: 'test-desc',
-        showInControlsMenu: true,
+        hide: VariableHide.inControlsMenu,
         datasource: { uid: 'fake-uid', type: 'fake-type' },
         filters: [
           {
@@ -1268,10 +1426,9 @@ describe('sceneVariablesSetToVariables', () => {
             "value": "test",
           },
         ],
-        "hide": "dontHide",
+        "hide": "inControlsMenu",
         "label": "test-label",
         "name": "test",
-        "showInControlsMenu": true,
         "skipUrlSync": false,
       },
     }
@@ -1283,7 +1440,7 @@ describe('sceneVariablesSetToVariables', () => {
         name: 'test',
         label: 'test-label',
         description: 'test-desc',
-        showInControlsMenu: true,
+        hide: VariableHide.inControlsMenu,
         datasource: { uid: 'fake-uid', type: 'fake-type' },
         defaultKeys: [
           {
@@ -1359,10 +1516,9 @@ describe('sceneVariablesSetToVariables', () => {
             "value": "test",
           },
         ],
-        "hide": "dontHide",
+        "hide": "inControlsMenu",
         "label": "test-label",
         "name": "test",
-        "showInControlsMenu": true,
         "skipUrlSync": false,
       },
     }
@@ -1383,7 +1539,7 @@ describe('sceneVariablesSetToVariables', () => {
           name: 'test',
           label: 'test-label',
           description: 'test-desc',
-          showInControlsMenu: true,
+          hide: VariableHide.inControlsMenu,
           datasource: { uid: 'fake-uid', type: 'fake-type' },
           defaultOptions: [
             {
@@ -1417,7 +1573,7 @@ describe('sceneVariablesSetToVariables', () => {
           },
           "defaultValue": undefined,
           "description": "test-desc",
-          "hide": "dontHide",
+          "hide": "inControlsMenu",
           "label": "test-label",
           "multi": true,
           "name": "test",
@@ -1431,7 +1587,6 @@ describe('sceneVariablesSetToVariables', () => {
               "value": "bar",
             },
           ],
-          "showInControlsMenu": true,
           "skipUrlSync": false,
         },
       }
@@ -1445,7 +1600,7 @@ describe('sceneVariablesSetToVariables', () => {
           name: 'test',
           label: 'test-label',
           description: 'test-desc',
-          showInControlsMenu: true,
+          hide: VariableHide.inControlsMenu,
           datasource: { uid: 'fake-uid', type: 'fake-type' },
           defaultOptions: [
             {
@@ -1465,5 +1620,100 @@ describe('sceneVariablesSetToVariables', () => {
         expect(() => sceneVariablesSetToSchemaV2Variables(set)).toThrow('Unsupported variable type');
       });
     });
+
+    it('should handle SwitchVariable with true value', () => {
+      const variable = new SwitchVariable({
+        name: 'test',
+        label: 'test-label',
+        description: 'test-desc',
+        hide: VariableHide.inControlsMenu,
+        value: 'true',
+        skipUrlSync: true,
+      });
+      const set = new SceneVariableSet({
+        variables: [variable],
+      });
+
+      const result = sceneVariablesSetToSchemaV2Variables(set);
+
+      expect(result).toHaveLength(1);
+      expect(result[0]).toMatchInlineSnapshot(`
+{
+  "kind": "SwitchVariable",
+  "spec": {
+    "current": "true",
+    "description": "test-desc",
+    "disabledValue": "false",
+    "enabledValue": "true",
+    "hide": "inControlsMenu",
+    "label": "test-label",
+    "name": "test",
+    "skipUrlSync": true,
+  },
+}
+`);
+    });
+
+    it('should handle SwitchVariable with false value', () => {
+      const variable = new SwitchVariable({
+        name: 'test',
+        label: 'test-label',
+        description: 'test-desc',
+        hide: VariableHide.inControlsMenu,
+        value: 'false',
+        skipUrlSync: false,
+      });
+      const set = new SceneVariableSet({
+        variables: [variable],
+      });
+
+      const result = sceneVariablesSetToSchemaV2Variables(set);
+
+      expect(result).toHaveLength(1);
+      expect(result[0]).toMatchInlineSnapshot(`
+{
+  "kind": "SwitchVariable",
+  "spec": {
+    "current": "false",
+    "description": "test-desc",
+    "disabledValue": "false",
+    "enabledValue": "true",
+    "hide": "inControlsMenu",
+    "label": "test-label",
+    "name": "test",
+    "skipUrlSync": false,
+  },
+}
+`);
+    });
+
+    it('should handle SwitchVariable with minimal configuration', () => {
+      const variable = new SwitchVariable({
+        name: 'minimal',
+        value: 'true',
+      });
+      const set = new SceneVariableSet({
+        variables: [variable],
+      });
+
+      const result = sceneVariablesSetToSchemaV2Variables(set);
+
+      expect(result).toHaveLength(1);
+      expect(result[0]).toMatchInlineSnapshot(`
+{
+  "kind": "SwitchVariable",
+  "spec": {
+    "current": "true",
+    "description": undefined,
+    "disabledValue": "false",
+    "enabledValue": "true",
+    "hide": "dontHide",
+    "label": undefined,
+    "name": "minimal",
+    "skipUrlSync": false,
+  },
+}
+`);
+    });
   });
 });
